@@ -12,7 +12,7 @@ pub trait StmtConvert {
 macro_rules! push_index {
      ($n:expr,$new_sql:ident,$index:expr) => {
                   {
-                     let mut num=$index/$n;
+                     let num=$index/$n;
                      $new_sql.push((num+48) as u8 as char);
                      $index % $n
                   }
