@@ -1,5 +1,5 @@
-use bson2::{bson, Bson, to_bson};
-use bson2::spec::BinarySubtype;
+use rbson::{bson, Bson, to_bson};
+use rbson::spec::BinarySubtype;
 use chrono::{Utc};
 use sqlx_core::column::Column;
 use sqlx_core::decode::Decode;
@@ -38,7 +38,7 @@ impl<'c> JsonCodec for SqliteValueRef<'c> {
             "BLOB" => {
                 let r: Option<Vec<u8>> = Decode::<'_, Sqlite>::decode(self)?;
                 if let Some(r) = r {
-                    return Ok(Bson::Binary(bson2::Binary {
+                    return Ok(Bson::Binary(rbson::Binary {
                         subtype: BinarySubtype::Generic,
                         bytes: r,
                     }));
@@ -65,7 +65,7 @@ impl<'c> JsonCodec for SqliteValueRef<'c> {
                 //you can use already supported types to decode this
                 let r: Option<Vec<u8>> = Decode::<'_, Sqlite>::decode(self)?;
                 if let Some(r) = r {
-                    return Ok(Bson::Binary(bson2::Binary {
+                    return Ok(Bson::Binary(rbson::Binary {
                         subtype: BinarySubtype::Generic,
                         bytes: r,
                     }));
@@ -80,7 +80,7 @@ impl RefJsonCodec for Vec<SqliteRow> {
     fn try_to_bson(&self, decoder: &dyn DataDecoder) -> crate::Result<Bson> {
         let mut arr = Vec::with_capacity(self.len());
         for row in self {
-            let mut m = bson2::Document::new();
+            let mut m = rbson::Document::new();
             let columns = row.columns();
             for x in columns {
                 let key = x.name();
