@@ -4,7 +4,7 @@ use std::str::FromStr;
 use rbson::Bson;
 use rbson::spec::BinarySubtype;
 use serde::{Deserializer, Serializer};
-use chrono::Utc;
+use chrono::{DateTime, Utc};
 use serde::de::Error;
 
 /// Rbatis DateTime Utc
@@ -67,6 +67,13 @@ impl<'de> serde::Deserialize<'de> for DateTimeUtc {
                     });
                 }
             }
+            //timestamp(ms)
+            Bson::Int64(timestamp) => {
+                let native=chrono::NaiveDateTime::from_timestamp(timestamp/1000, (timestamp % 1000 * 1000000) as u32);
+                return Ok(DateTimeUtc {
+                    inner: DateTime::<Utc>::from_utc(native,Utc)
+                });
+            }
             _ => {
                 Err(D::Error::custom("deserialize un supported bson type!"))
             }
