@@ -1,3 +1,4 @@
+use std::any::type_name;
 use std::ops::{Deref, DerefMut};
 use std::str::FromStr;
 use rbson::{Binary, Bson};
@@ -49,7 +50,12 @@ impl From<rbson::Binary> for Uuid {
 impl serde::Serialize for Uuid {
     #[inline]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where S: Serializer {
-        return serializer.serialize_str(&format!("Uuid({})", self.inner));
+        use serde::ser::Error;
+        if type_name::<S::Error>().eq("rbson::ser::error::Error") {
+            return serializer.serialize_str(&format!("Uuid({})", self.inner));
+        }else {
+            return self.inner.serialize(serializer);
+        }
     }
 }
 
